package org.gcube.informationsystem.model.discovery;

import java.util.List;
import java.util.ServiceLoader;

import org.gcube.informationsystem.model.impl.utils.discovery.ISMDiscovery;
import org.gcube.informationsystem.model.impl.utils.discovery.RegistrationProvider;
import org.gcube.informationsystem.model.reference.ISManageable;
import org.gcube.informationsystem.model.reference.embedded.Embedded;
import org.gcube.informationsystem.model.reference.entity.Entity;
import org.gcube.informationsystem.model.reference.relation.Relation;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ISMDiscoveryTest {

	private static Logger logger = LoggerFactory.getLogger(ISMDiscovery.class);
	
	private void addDiscoveredModel(ISMDiscovery<? extends ISManageable> ismDiscovery) {
		ServiceLoader<? extends RegistrationProvider> regsitrationProviders = ServiceLoader.load(RegistrationProvider.class);
		for (RegistrationProvider registrationProvider : regsitrationProviders) {
			List<Package> packages = registrationProvider.getPackagesToRegister();
			for(Package p : packages) {
				ismDiscovery.addPackage(p);
			}
		}
	}
	
	@Test
	public void testEmbeddedDiscovery() throws Exception{
		ISMDiscovery<Embedded> embeddedDiscovery = new ISMDiscovery<>(Embedded.class);
		addDiscoveredModel(embeddedDiscovery);
		embeddedDiscovery.discover();
		
		for(Class<Embedded> embedded : embeddedDiscovery.getDiscovered()) {
			logger.info("Going to create : {}", embedded);
		}
	}
	
	@Test
	public void testEntityDiscovery() throws Exception{
		ISMDiscovery<Entity> entityDiscovery = new ISMDiscovery<>(Entity.class);
		addDiscoveredModel(entityDiscovery);
		entityDiscovery.discover();
		
		for(Class<Entity> entity : entityDiscovery.getDiscovered()) {
			logger.info("Going to create : {}", entity);
		}
	}
	
	@Test
	public void testRelationDiscovery() throws Exception{
		@SuppressWarnings("rawtypes")
		ISMDiscovery<Relation> relationDiscovery = new ISMDiscovery<>(Relation.class);
		addDiscoveredModel(relationDiscovery);
		relationDiscovery.discover();
	}
	
	
	
}
